; Add this file to the end of your .emacs file or load this file from your .emacs file.
; On a PC, place the .emacs file in c:/.
; On unix, put the .emacs file in the root of your home directory.

; loads the LAML emacs support
(load "@laml-dir@laml.el") 

; loads the Scheme Elucidator Emacs support
(load "@laml-dir@styles/elucidator/elucidator.el")  

(defun laml-customize ()
  (interactive)
  (customize-group 'laml))

; -----------------------------------------------------------------------------
; Laml mode key bindings.

; Arrange that C-o starts asynchronous laml processing
(define-key laml-mode-map "\C-o" 'laml-process-current-buffer)

; Arrange that C-x C-o starts synchronous laml processing
(define-key laml-mode-map "\C-x\C-o" 'laml-sync-process-current-buffer)

; Arrange that C-x C-n calls the LAML nest command:
(define-key laml-mode-map "\C-x\C-n" 'nest)

; Arrange that C-x C-m calls the LAML unnest command:
(define-key laml-mode-map "\C-x\C-m" 'unnest)

; Arrange that C-x C-e calls the LAML embed command:
(define-key laml-mode-map "\C-x\C-e" 'embed)

; Arrange that C-x C-r calls the LAML unembed command:
(define-key laml-mode-map "\C-x\C-r" 'unembed)

; Arrange that C-x C-q calls the LAML split command:
(define-key laml-mode-map "\C-x\C-q" 'split)

; Arrange that C-x C-a calls the LAML unsplit command:
(define-key laml-mode-map "\C-x\C-a" 'unsplit)

; Arrange that C-M-q indents the currently selected S-expression
(define-key laml-mode-map "\C-\M-q" 'indent-sexp)

; Arrange that TAB (C-i) runs indent-for-tab-command, as in Scheme mode.
(define-key laml-mode-map "\C-i" 'indent-for-tab-command)

; Arrange that C-M-x activates lisp-eval-defun (definition af Lisp expression in inferior Lisp job).
(define-key laml-mode-map "\C-\M-x" 'lisp-eval-defun)

; An alais to lisp-eval-defun
(define-key laml-mode-map "\C-c\C-e" 'lisp-eval-defun)

; Arrange that C-c C-r activates lisp-eval-region (definition af Lisp expressions in inferior Lisp job).
(define-key laml-mode-map "\C-c\C-r" 'lisp-eval-region)

; Leno Laml mode key bindings
(define-key laml-mode-map "\C-l\C-a" 'insert-notesection)
(define-key laml-mode-map "\C-l\C-b" 'insert-notepage)
(define-key laml-mode-map "\C-l\C-p" 'insert-point)
(define-key laml-mode-map "\C-l\C-i" 'insert-items)
(define-key laml-mode-map "\C-l\C-u" 'insert-items-without-annotations)
(define-key laml-mode-map "\C-l\C-s" 'insert-slide-space)
(define-key laml-mode-map "\C-i" 'goto-next-input-field)

; -----------------------------------------------------------------------------
; Laml mode menu bindings.

(define-key laml-mode-map [menu-bar laml]
    (cons "Laml" (make-sparse-keymap "Laml")))


; -----------------------------------------------------------------------------
; Templates:

(define-key laml-mode-map [menu-bar laml laml-insert-template]
    (cons "Insert LAML template" (make-sparse-keymap "laml-templates")))

(define-key laml-mode-map [menu-bar laml laml-insert-template other]
      '("Prompt me..." . laml-insert-template))

(define-key laml-mode-map [menu-bar laml laml-insert-template generic-page-xhtml-strict]
      '("XHTML1.0 strict page" . (lambda () (interactive) (laml-insert-template "generic-page-xhmtl1-strict"))))

(define-key laml-mode-map [menu-bar laml laml-insert-template generic-page]
      '("HTML4.01 transitional page" . (lambda () (interactive) (laml-insert-template "generic-page"))))


; ----------------------------------------------------------------------------------------

; LENO:

(define-key laml-mode-map [menu-bar laml menu-forms-sep5]
    '("----"))

(define-key laml-mode-map [menu-bar laml leno]
    (cons "Leno" (make-sparse-keymap "Leno")))

(define-key laml-mode-map [menu-bar laml leno make-lecture-notes]
      '("Make new lecture notes" . make-lecture-notes))

(define-key laml-mode-map [menu-bar laml leno menu-forms-sep6]
    '("----"))

(define-key laml-mode-map [menu-bar laml leno insert-show-and-speak]
    '("Insert show-and-speak" . insert-show-and-speak))

(define-key laml-mode-map [menu-bar laml leno insert-quiz]
    '("Insert quiz" . insert-quiz))

(define-key laml-mode-map [menu-bar laml leno insert-comment]
    '("Insert comment" . insert-comment))

(define-key laml-mode-map [menu-bar laml leno insert-side-track]
    '("Insert sidetrack" . insert-side-track))

(define-key laml-mode-map [menu-bar laml leno insert-splice-page-without]
    '("Insert splice page without" . insert-splice-page-without))

(define-key laml-mode-map [menu-bar laml leno insert-splice-page-with]
    '("Insert splice page with" . insert-splice-page-with))


(define-key laml-mode-map [menu-bar laml leno insert-lecturer-photos]
    '("Insert lecturer photos" . insert-lecturer-photos))

(define-key laml-mode-map [menu-bar laml leno insert-lecturer-photos-and-logo]
    '("Insert photos and logo" . insert-lecturer-photos-and-logo))

(define-key laml-mode-map [menu-bar laml leno insert-elucidate]
    '("Insert elucidate" . insert-elucidate))

(define-key laml-mode-map [menu-bar laml leno insert-text]
    '("Insert text" . insert-text))


(define-key laml-mode-map [menu-bar laml leno insert-source-program]
    '("Insert source-program" . insert-source-program))

(define-key laml-mode-map [menu-bar laml leno insert-image]
    '("Insert image" . insert-image))

(define-key laml-mode-map [menu-bar laml leno insert-example]
    '("Insert example" . insert-example))

(define-key laml-mode-map [menu-bar laml leno insert-syntax]
    '("Insert syntax" . insert-syntax))

(define-key laml-mode-map [menu-bar laml leno insert-slide-space]
    '("Insert slide space" . insert-slide-space))

(define-key laml-mode-map [menu-bar laml leno insert-tabular]
    '("Insert tabular" . insert-tabular))

(define-key laml-mode-map [menu-bar laml leno insert-note-text]
    '("Insert note text" . insert-note-text))

(define-key laml-mode-map [menu-bar laml leno insert-slide-text]
    '("Insert slide text" . insert-slide-text))

(define-key laml-mode-map [menu-bar laml leno insert-cross-references]
    '("Insert cross references" . insert-cross-references))

(define-key laml-mode-map [menu-bar laml leno insert-internet-reference]
    '("Insert internet reference" . insert-internet-reference))

(define-key laml-mode-map [menu-bar laml leno insert-note-reference]
    '("Insert note reference" . insert-note-reference))

(define-key laml-mode-map [menu-bar laml leno insert-informal-reference]
    '("Insert informal reference" . insert-informal-reference))

(define-key laml-mode-map [menu-bar laml leno insert-bibtex-reference]
    '("Insert BibTex reference" . insert-bibtex-reference))

(define-key laml-mode-map [menu-bar laml leno insert-exercise]
    '("Insert exercise" . insert-exercise))

(define-key laml-mode-map [menu-bar laml leno insert-long-slide]
    '("Insert long slide" . insert-long-slide))

(define-key laml-mode-map [menu-bar laml leno insert-index-words]
    '("Insert index words" . insert-index-words))

(define-key laml-mode-map [menu-bar laml leno insert-image-series]
    '("Insert image series" . insert-image-series))

(define-key laml-mode-map [menu-bar laml leno insert-section-title]
    '("Insert section title" . insert-section-title))

(define-key laml-mode-map [menu-bar laml leno insert-slide-image]
    '("Insert slide image" . insert-slide-image))

(define-key laml-mode-map [menu-bar laml leno insert-applet-program]
    '("Insert applet program" . insert-applet-program))

(define-key laml-mode-map [menu-bar laml leno insert-quotation]
    '("Insert quotation" . insert-quotation))

(define-key laml-mode-map [menu-bar laml leno insert-opposing]
      '("Insert opposing items" . insert-opposing))

(define-key laml-mode-map [menu-bar laml leno insert-concept-list]
      '("Insert concept list" . insert-concept-list))

(define-key laml-mode-map [menu-bar laml leno insert-synopsis]
      '("Insert synopsis" . insert-synopsis))

(define-key laml-mode-map [menu-bar laml leno insert-title]
    '("Insert title" . insert-title))

(define-key laml-mode-map [menu-bar laml leno insert-point]
    '("Insert point" . insert-point))

(define-key laml-mode-map [menu-bar laml leno insert-simple-items]
      '("Insert simple items" . insert-items-without-annotations))

(define-key laml-mode-map [menu-bar laml leno insert-items]
      '("Insert items" . insert-items))

(define-key laml-mode-map [menu-bar laml leno menu-forms-sep7]
    '("----"))

(define-key laml-mode-map [menu-bar laml leno insert-notepage]
      '("Insert note page" . insert-notepage))

(define-key laml-mode-map [menu-bar laml leno insert-notesection]
      '("Insert note section page" . insert-notesection))

; End LENO bindings


; Elucidator bindings

(define-key laml-mode-map [menu-bar laml elucidator]
     (cons "Elucidator" (make-sparse-keymap "Elucidator")))

 
; (define-key laml-mode-map [menu-bar laml elucidator insert-sectional-comment]
;     '("insert sectional comment" . insert-sectional-comment))
; 
; (define-key laml-mode-map [menu-bar laml elucidator elucidator-show-processing]
;     '("elucidator show processing" . elucidator-show-processing))
; 
; (define-key laml-mode-map [menu-bar laml elucidator elucidator-let-be]
;     '("elucidator let be" . elucidator-let-be))
; 
; (define-key laml-mode-map [menu-bar laml elucidator insert-documentation-entry]
;     '("insert documentation entry" . insert-documentation-entry))
; 
; (define-key laml-mode-map [menu-bar laml elucidator insert-documentation-section]
;     '("insert documentation section" . insert-documentation-section))
; 
; (define-key laml-mode-map [menu-bar laml elucidator large-program-window]
;     '("large program window" . large-program-window))
; 
; (define-key laml-mode-map [menu-bar laml elucidator large-documentation-window]
;     '("large documentation window" . large-documentation-window))
;
; (define-key laml-mode-map [menu-bar laml elucidator back]
;     '("go back" . back))
; 
; (define-key laml-mode-map [menu-bar laml elucidator goto]
;     '("goto" . goto))
; 
; (define-key laml-mode-map [menu-bar laml elucidator doc-ref]
;     '("insert doc ref" . doc-ref))
;
;(define-key laml-mode-map [menu-bar laml elucidator elucidate]
;    '("elucidate" . elucidate))
; 
; (define-key laml-mode-map [menu-bar laml elucidator surround-none-ref]
;     '("surround prog ref - none" . surround-none-ref))
; 
; (define-key laml-mode-map [menu-bar laml elucidator surround-prog-ref]
;     '("surround prog ref" . surround-prog-ref))
; 
; (define-key laml-mode-map [menu-bar laml elucidator prog-ref]
;     '("insert prog ref" . prog-ref))



(define-key laml-mode-map [menu-bar laml elucidator elucidator-help]
    '("elucidator help" . elucidator-help))

(define-key laml-mode-map [menu-bar laml elucidator elucidator-status]
    '("elucidator status" . elucidator-status))

(define-key laml-mode-map [menu-bar laml elucidator show-setup]
    '("show setup" . show-setup))

(define-key laml-mode-map [menu-bar laml elucidator refresh-elucidator]
    '("refresh elucidator" . refresh-elucidator))

(define-key laml-mode-map [menu-bar laml elucidator show-program]
    '("show program" . show-program))

(define-key laml-mode-map [menu-bar laml elucidator reset-elucidator]
    '("reset elucidator" . reset-elucidator))

(define-key laml-mode-map [menu-bar laml elucidator setup-elucidator]
    '("setup elucidator" . setup-elucidator))

(define-key laml-mode-map [menu-bar laml elucidator make-elucidator]
    '("make elucidator" . make-elucidator))

(define-key laml-mode-map [menu-bar laml menu-forms-sep4]
    '("----"))


; End Elucidator bindings

(define-key laml-mode-map [menu-bar laml run-laml-interactively]
      '("Run LAML interatively" . run-laml-interactively))


; Main LAML menu entries

(define-key laml-mode-map [menu-bar laml laml-customize]
      '("Customize LAML" . laml-customize))


(define-key laml-mode-map [menu-bar laml menu-forms-sep3]
    '("----"))

; -----------------------------------------------------------------------------
; Scheme evaluation

(define-key laml-mode-map [menu-bar laml scheme-eval]
     (cons "Evaluate Scheme form(s)" (make-sparse-keymap "Scheme evaluation")))

(define-key laml-mode-map [menu-bar laml scheme-eval lisp-eval-buffer]
      '("Entire buffer" . (lambda () (interactive) (lisp-eval-region (point-min) (point-max)))))

(define-key laml-mode-map [menu-bar laml scheme-eval lisp-eval-region]
      '("Current selection" . lisp-eval-region))

(define-key laml-mode-map [menu-bar laml scheme-eval lisp-eval-defun]
      '("Current form" . lisp-eval-defun))

; -----------------------------------------------------------------------------


(define-key laml-mode-map [menu-bar laml indent-sexp]
      '("Indent symbolic expression" . indent-sexp))

; -----------------------------------------------------------------------------

(define-key laml-mode-map [menu-bar laml menu-forms-sep2]
    '("----"))

(define-key laml-mode-map [menu-bar laml unnest]
      '("Unnest" . unnest))

(define-key laml-mode-map [menu-bar laml nest]
      '("Nest form in form" . nest))

(define-key laml-mode-map [menu-bar laml unsplit]
      '("Unsplit" . unsplit))

(define-key laml-mode-map [menu-bar laml split]
      '("Split string" . split))

(define-key laml-mode-map [menu-bar laml unembed]
      '("Unembed" . unembed))

(define-key laml-mode-map [menu-bar laml embed]
      '("Embed string in form" . embed))

(define-key laml-mode-map [menu-bar laml menu-forms-sep1]
    '("----"))

(define-key laml-mode-map [menu-bar laml process-sync]
      '("Process syncronously" . laml-sync-process-current-buffer))

(define-key laml-mode-map [menu-bar laml process-async]
      '("Process asyncronously" . laml-process-current-buffer))

; End main LAML menu entries






