; This file is generated by the program tools/tools/html-mirroring-from-dtd/laml-mirror-via-dtd.scm. Do not edit!

;;;; This the an accurate mirror of XHMTL1.0 (frameset) on surface form. A surface form has a very flexible syntactic composition. Use the surface forms when you write an HTML document in LAML syntax. Each function in this file mirrors and generates an HTML tag. The general form of a surface mirror function is <pre>   (tag 'a1 "v1" 'a2 "v2" ... 'am "vm" contents-1 contents-2 ... contents-n). </pre>where, in the most common case, <kbd>contents-1</kbd>, <kbd>contents-2</kbd> through <kbd>contents-n</kbd> are strings which are string-appended to form the contents of the element. From LAML version 16.2 <kbd>contents-i</kbd> (i from 1 to n) can also be proper lists of strings which automatically are string-appended to form a single content string. The attribute names must be symbols, and the attribute values have to be strings.<p>The expression from above corresponds to the HTML tag <pre>   &lt;tag a1 "v1" a2 "v2" ... am "vm"&gt; contents-1 contents-2 ... contents-n &lt;/tag&gt;</pre>In the Scheme form it is even possible to have attributes between and after the textual content. Attributes prefixed with 'css:' are CSS style attributes.<p>Unless stated otherwise there will be a space character between contents strings, such as in between <kbd>contents-1</kbd> and <kbd>contents-2</kbd>. A boolean value false in between the contents strings, such as between <kbd>contents-1</kbd> and <kbd>contents-2</kbd>, suppresses white space in between them. This is in particular useful before punctuation characters. We recommend that you bind #f to a notationally convenient variable such as '_'. <p>If the boolean variable <kbd>check-html-attributes?</kbd> is true the functions check the attributes of the tag against the attribute definitions in the document type definition. <p>The HTML mirror functions emit non-pretty printed HTML code. If you want pretty printed HTML you can use the <a href = "../../../tools/xml-html-support/man/html-support.html">HTML pretty printer</a>, which is part of the LAML software package. See also the <a href = "../../../man/laml.html#html-pp">html-pp</a> procedure. Notice that pretty printing may be quite expensive compared with the generation as such.<p>This library requries the general library and the accompanying basic form library. <p>Notice that the function map and the HTML element map give a name collision.We prefix the HTML element with 'html:' when applied as a HTML mirror function in LAML.<p>This library provides links to the <a href = "../../../html-doc/html401/cover.html">W3 document which defines the HTML tags</a>. The underlying WWW pages are supplied as part of the LAML software bundle.<p>See also the <a href = "basis.html">basic form library</a> of the mirror and the HTML <a href = "convenience.html">convenience library</a>.

; Return an HTML mirror surface function, in which textual content parameters and attribute
; value pairs can be given in a very liberal fashion.
; html-basic-function is the name of an HTML basic mirror function to be called once we have
; sorted out contents and attributes of the present form.
; Tag-name is a string which represents the name of the tag (used for error message purposes).
; single-double-kind is either the symbol single, double or possible-single.
; The generated surface function is made efficient (avoiding parameter sorting) in the following special cases:
; (1) single-tag, no attributes.
; (2) double-tag, one string contents parameter.
(define (generate-html-surface-function html-basic-function tag-name single-double-kind)
 (cond ((eq? single-double-kind 'double)
          (lambda parameters
            (if (and (pair? parameters) (string? (car parameters)) (null? (cdr parameters)))
                (apply html-basic-function (cons (car parameters) '())) ; efficient handling of double tag with 
                                                                        ; a single string contents parameter
                (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
		       (contents (car contents-attributes))
		       (attributes (cdr contents-attributes))
                      )
		  (apply html-basic-function (cons contents attributes)))
            )
          )
       )

       ((eq? single-double-kind 'single)   
          (lambda parameters
            (if (null? parameters)
                (apply html-basic-function '())  ; efficient handling of single tag with no attributes
                (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
		       (contents (car contents-attributes))
		       (attributes (cdr contents-attributes))
                      )
		  (check-for-empty-contents! contents tag-name)
		  (apply html-basic-function attributes))
            )
          )
       )

       ((eq? single-double-kind 'possible-single)   
          (lambda parameters
            (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
                   (contents (car contents-attributes))
                   (attributes (cdr contents-attributes))
                  )
               (if (empty-string? contents) ; generate single tag
                   (apply html-basic-function (cons #f attributes))
                   (apply html-basic-function (cons contents attributes))
               )
            )
          )
       )

       (else (error (string-append "generate-html-surface-function: unknown single-double-kind: " (as-string single-double-kind))))
 )
)

; Previous less efficient version:
; (define (generate-html-surface-function html-basic-function tag-name single-double-kind)
;   (lambda parameters
;    (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
;           (contents (car contents-attributes))
;           (attributes (cdr contents-attributes)))
;      (cond ((eq? single-double-kind 'double)
;                (apply html-basic-function (cons contents attributes)))
;            ((and (eq? single-double-kind 'possible-single) (empty-string? contents))  ; generate single tag
;                (apply html-basic-function (cons #f attributes)))
;            ((and (eq? single-double-kind 'possible-single) (not (empty-string? contents)))  ; generate double tag
;                (apply html-basic-function (cons contents attributes)))
;            (else 
;              (begin
;                (check-for-empty-contents! contents tag-name)
;                (apply html-basic-function attributes)))))))

(define (check-for-empty-contents! contents tag-name)
  (if (not (empty-string? contents))
      (display-warning (string-append "The single tag " tag-name " is not supposed to have any contents: " contents ". We just skip it."))))

; Return a pair of contents string and a property list of attributes from parameters.
(define (sort-tag-parameters parameters tag-name)
 (let ((res (sort-tag-parameters-1 parameters parameters "" '() tag-name)))
   (cons (strip-trailing-space (car res)) ; ensure that there are no trailing space in the contents
         (cdr res))))

; Process iteratively the parameters. Handle boolean values after contents contribution. Boolean #f suppress
; interspacing. Boolean #t or no boolean value adds interspacing. Also collect attribute keys and values.
; original-parameters are carried through the recursive call, and used for error message purposes.
(define (sort-tag-parameters-1 original-parameters parameters contents attributes tag-name)
  (cond ((null? parameters) (cons contents (reverse attributes)))
        ((and (string? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters)) (not (cadr parameters)))  ; no space after
                 (sort-tag-parameters-1 original-parameters (cddr parameters) (string-append contents (car parameters)) attributes tag-name))
        ((and (string? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters)) (cadr parameters))        ; space after
                 (sort-tag-parameters-1 original-parameters
                                        (cddr parameters) (string-append contents (car parameters) " " ) attributes tag-name))
        ((string? (car parameters))   ; space after
                 (sort-tag-parameters-1 original-parameters 
                                        (cdr parameters) (string-append contents (car parameters) " ") attributes tag-name))
        ((and (list? (car parameters)))
                 (sort-tag-parameters-1 original-parameters
                                        (cdr parameters) 
                                        (string-append contents (list-to-element-contents (car parameters)) " " ) attributes tag-name))
        ((and (symbol? (car parameters)) (not (null? (cdr parameters))) (not (boolean? (cadr parameters))))
           (let ((attr-name (car parameters))
                 (attr-val (cadr parameters)))
             (sort-tag-parameters-1 original-parameters (cddr parameters) contents (cons attr-val (cons attr-name attributes)) tag-name)))
        ((symbol? (car parameters)) (sort-error (string-append "Attributes of the " tag-name
                                    " tag must be of the form 'symbol \"value\". Only the symbol " (as-string (car parameters))
                                    " appears in last attribute") original-parameters))
        (else (sort-error (string-append "Error in an LAML " tag-name " tag.") original-parameters))
  ))

; Return the string corresponding to the element contents of lst.
; As of this version, no kinds of white space is added automatically.
(define (list-to-element-contents lst)
  (apply string-append lst))

(define (sort-error message parameters)
 (let* ((max-str-lgt 80)  ; symbolic constant definition
        (parameters-1 (as-quoted-string parameters))
        (parameters-2 (if (> (string-length parameters-1) max-str-lgt) 
                        (string-append (substring parameters-1 0 (- max-str-lgt 1)) "...")
                        parameters-1)))
  (error
    (string-append
      message (as-string #\newline)
      "  FORM CONTENTS AND ATTR.: " parameters-2 (as-string #\newline)))))
      

;;; Other useful functions. 
;;; In this section there are non-mirror functions which are useful in surface HTML forms.

;; A non-HTML tag which concatenates parameters of a form to a single string. 
;; There may be boolean values among the parameters.
;; A boolean false after a textual contents string suppresses white space after the contents string.
;; Warn if there are attributes among the parameters. Possible attributes are just skipped.
(define (concatenate . parameters)
  (let* ((res-pair (sort-tag-parameters parameters "concatenate function"))
         (contents (car res-pair))
         (attributes (cdr res-pair)))
    (if (not (null? attributes))
        (display-warning 
          (string-append "There are attribute value pairs in a context assumed to pure textual contents: " (as-string attributes) ". "
                         "I just discarded these.")))
    contents))
 

; Strip trailing space - only one space character is stripped.
(define (strip-trailing-space str)
 (let ((lgt (string-length str)))
  (cond ((empty-string? str) "")
        ((eq? (string-ref str (- lgt 1)) #\space)  ; last character is space
          (substring str 0 (- lgt 1)))
        (else str))))

;; Generate a HTML tag application for tag-name with attributes and contents
;; given by parameters. The parameters obeys the syntax of a the LAML surface forms.
;; This function is useful for generation of non-standard tag applications.
(define (free-html-element tag-name . parameters)
 (let* ((cont-attr (sort-tag-parameters parameters tag-name))
        (cont (car cont-attr))
        (attr (cdr cont-attr)))
   (if (empty-string? cont)
       (itag1 tag-name attr)
       (itag tag-name cont attr))))

;; Generate a HTML tag application for tag-name with attributes and contents given by parameters.
;; This function corresponds exactly to free-html-element; however, this function takes exactly two
;; parameters whereas free-html-elements takes one or more parameters.
(define (free-html-element-1 tag-name parameters)
 (let* ((cont-attr (sort-tag-parameters parameters tag-name))
        (cont (car cont-attr))
        (attr (cdr cont-attr)))
   (if (empty-string? cont)
       (itag1 tag-name attr)
       (itag tag-name cont attr))))

;; Define partial attributes and element contents of element and return a new element function
;; with the attributes and contents partially fixed.
;; attributes-and-contents is of the same form as the parameters to a LAML surface mirror functions.
;; In fact, attributes-and-contents are just appended to the actual parameters to the modified.
;; .example (define a-main (modify-element a 'target "main"))
;; .returns an attribute-modified mirror function
(define (modify-element element . attributes-and-contents)
  (lambda parameters (apply element (append parameters attributes-and-contents))))

;;; The HTML surface mirror functions

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TD</b> double tag element (<em>no explanation available</em>). <br>
;; .form (td . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, abbr, axis, headers, scope, rowspan, colspan, align, char, charoff, valign, nowrap, bgcolor, width, height. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:td" "basis.html#xhtml1:td"
(define td (generate-html-surface-function xhtml1:td "td" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TH</b> double tag element (<em>no explanation available</em>). <br>
;; .form (th . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, abbr, axis, headers, scope, rowspan, colspan, align, char, charoff, valign, nowrap, bgcolor, width, height. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:th" "basis.html#xhtml1:th"
(define th (generate-html-surface-function xhtml1:th "th" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TR</b> double tag element (<em>no explanation available</em>). <br>
;; .form (tr . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign, bgcolor. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:tr" "basis.html#xhtml1:tr"
(define tr (generate-html-surface-function xhtml1:tr "tr" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>COL</b> single tag element (<em>no explanation available</em>). <br>
;; .form (col . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, span, width, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:col" "basis.html#xhtml1:col"
(define col (generate-html-surface-function xhtml1:col "col" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>COLGROUP</b> double tag element (<em>no explanation available</em>). <br>
;; .form (colgroup . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, span, width, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:colgroup" "basis.html#xhtml1:colgroup"
(define colgroup (generate-html-surface-function xhtml1:colgroup "colgroup" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TBODY</b> double tag element (<em>no explanation available</em>). <br>
;; .form (tbody . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:tbody" "basis.html#xhtml1:tbody"
(define tbody (generate-html-surface-function xhtml1:tbody "tbody" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TFOOT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (tfoot . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:tfoot" "basis.html#xhtml1:tfoot"
(define tfoot (generate-html-surface-function xhtml1:tfoot "tfoot" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>THEAD</b> double tag element (<em>no explanation available</em>). <br>
;; .form (thead . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:thead" "basis.html#xhtml1:thead"
(define thead (generate-html-surface-function xhtml1:thead "thead" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>CAPTION</b> double tag element (<em>no explanation available</em>). <br>
;; .form (caption . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:caption" "basis.html#xhtml1:caption"
(define caption (generate-html-surface-function xhtml1:caption "caption" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TABLE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (table . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, summary, width, border, frame, rules, cellspacing, cellpadding, align, bgcolor. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:table" "basis.html#xhtml1:table"
(define table (generate-html-surface-function xhtml1:table "table" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>ISINDEX</b> single tag element (<em>no explanation available</em>). <br>
;; .form (isindex . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, prompt. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:isindex" "basis.html#xhtml1:isindex"
(define isindex (generate-html-surface-function xhtml1:isindex "isindex" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>BUTTON</b> double tag element (<em>no explanation available</em>). <br>
;; .form (button . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, value, type, disabled, tabindex, accesskey, onfocus, onblur. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:button" "basis.html#xhtml1:button"
(define button (generate-html-surface-function xhtml1:button "button" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>LEGEND</b> double tag element (<em>no explanation available</em>). <br>
;; .form (legend . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, accesskey, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:legend" "basis.html#xhtml1:legend"
(define legend (generate-html-surface-function xhtml1:legend "legend" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>FIELDSET</b> double tag element (<em>no explanation available</em>). <br>
;; .form (fieldset . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:fieldset" "basis.html#xhtml1:fieldset"
(define fieldset (generate-html-surface-function xhtml1:fieldset "fieldset" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TEXTAREA</b> double tag element (<em>no explanation available</em>). <br>
;; .form (textarea . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: rows, cols. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, disabled, readonly, tabindex, accesskey, onfocus, onblur, onselect, onchange. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:textarea" "basis.html#xhtml1:textarea"
(define textarea (generate-html-surface-function xhtml1:textarea "textarea" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>OPTION</b> double tag element (<em>no explanation available</em>). <br>
;; .form (option . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, selected, disabled, label, value. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:option" "basis.html#xhtml1:option"
(define option (generate-html-surface-function xhtml1:option "option" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>OPTGROUP</b> double tag element (<em>no explanation available</em>). <br>
;; .form (optgroup . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: label. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, disabled. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:optgroup" "basis.html#xhtml1:optgroup"
(define optgroup (generate-html-surface-function xhtml1:optgroup "optgroup" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>SELECT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (select . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, size, multiple, disabled, tabindex, onfocus, onblur, onchange. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:select" "basis.html#xhtml1:select"
(define select (generate-html-surface-function xhtml1:select "select" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>INPUT</b> single tag element (<em>no explanation available</em>). <br>
;; .form (input . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, name, value, checked, disabled, readonly, size, maxlength, src, alt, usemap, tabindex, accesskey, onfocus, onblur, onselect, onchange, accept, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:input" "basis.html#xhtml1:input"
(define input (generate-html-surface-function xhtml1:input "input" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>LABEL</b> double tag element (<em>no explanation available</em>). <br>
;; .form (label . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, for, accesskey, onfocus, onblur. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:label" "basis.html#xhtml1:label"
(define label (generate-html-surface-function xhtml1:label "label" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>FORM</b> double tag element (<em>no explanation available</em>). <br>
;; .form (form . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: action. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, method, name, enctype, onsubmit, onreset, accept, accept-charset, target. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:form" "basis.html#xhtml1:form"
(define form (generate-html-surface-function xhtml1:form "form" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>AREA</b> single tag element (<em>no explanation available</em>). <br>
;; .form (area . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: alt. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, shape, coords, href, nohref, tabindex, accesskey, onfocus, onblur, target. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:area" "basis.html#xhtml1:area"
(define area (generate-html-surface-function xhtml1:area "area" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>XHTML:MAP</b> double tag element (<em>no explanation available</em>). <br>
;; .form (xhtml:map . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: id. <p>Optional attributes: lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, class, style, title, name. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:map" "basis.html#xhtml1:map"
(define xhtml:map (generate-html-surface-function xhtml1:map "xhtml:map" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>IMG</b> single tag element (<em>no explanation available</em>). <br>
;; .form (img . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: src, alt. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, longdesc, height, width, usemap, ismap, align, border, hspace, vspace. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:img" "basis.html#xhtml1:img"
(define img (generate-html-surface-function xhtml1:img "img" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>APPLET</b> double tag element (<em>no explanation available</em>). <br>
;; .form (applet . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: width, height. <p>Optional attributes: id, class, style, title, codebase, archive, code, object, alt, name, align, hspace, vspace. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:applet" "basis.html#xhtml1:applet"
(define applet (generate-html-surface-function xhtml1:applet "applet" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>PARAM</b> single tag element (<em>no explanation available</em>). <br>
;; .form (param . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: name. <p>Optional attributes: id, value, valuetype, type. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:param" "basis.html#xhtml1:param"
(define param (generate-html-surface-function xhtml1:param "param" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>OBJECT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (object . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, declare, classid, codebase, data, type, codetype, archive, standby, height, width, usemap, name, tabindex, align, border, hspace, vspace. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:object" "basis.html#xhtml1:object"
(define object (generate-html-surface-function xhtml1:object "object" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>FONT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (font . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, size, color, face. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:font" "basis.html#xhtml1:font"
(define font (generate-html-surface-function xhtml1:font "font" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>BASEFONT</b> single tag element (<em>no explanation available</em>). <br>
;; .form (basefont . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: size. <p>Optional attributes: id, color, face. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:basefont" "basis.html#xhtml1:basefont"
(define basefont (generate-html-surface-function xhtml1:basefont "basefont" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>STRIKE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (strike . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:strike" "basis.html#xhtml1:strike"
(define strike (generate-html-surface-function xhtml1:strike "strike" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>S</b> double tag element (<em>no explanation available</em>). <br>
;; .form (s . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:s" "basis.html#xhtml1:s"
(define s (generate-html-surface-function xhtml1:s "s" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>U</b> double tag element (<em>no explanation available</em>). <br>
;; .form (u . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:u" "basis.html#xhtml1:u"
(define u (generate-html-surface-function xhtml1:u "u" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>SMALL</b> double tag element (<em>no explanation available</em>). <br>
;; .form (small . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:small" "basis.html#xhtml1:small"
(define small (generate-html-surface-function xhtml1:small "small" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>BIG</b> double tag element (<em>no explanation available</em>). <br>
;; .form (big . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:big" "basis.html#xhtml1:big"
(define big (generate-html-surface-function xhtml1:big "big" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>B</b> double tag element (<em>no explanation available</em>). <br>
;; .form (b . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:b" "basis.html#xhtml1:b"
(define b (generate-html-surface-function xhtml1:b "b" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>I</b> double tag element (<em>no explanation available</em>). <br>
;; .form (i . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:i" "basis.html#xhtml1:i"
(define i (generate-html-surface-function xhtml1:i "i" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (tt . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:tt" "basis.html#xhtml1:tt"
(define tt (generate-html-surface-function xhtml1:tt "tt" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>SUP</b> double tag element (<em>no explanation available</em>). <br>
;; .form (sup . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:sup" "basis.html#xhtml1:sup"
(define sup (generate-html-surface-function xhtml1:sup "sup" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>SUB</b> double tag element (<em>no explanation available</em>). <br>
;; .form (sub . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:sub" "basis.html#xhtml1:sub"
(define sub (generate-html-surface-function xhtml1:sub "sub" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>Q</b> double tag element (<em>no explanation available</em>). <br>
;; .form (q . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:q" "basis.html#xhtml1:q"
(define q (generate-html-surface-function xhtml1:q "q" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>ACRONYM</b> double tag element (<em>no explanation available</em>). <br>
;; .form (acronym . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:acronym" "basis.html#xhtml1:acronym"
(define acronym (generate-html-surface-function xhtml1:acronym "acronym" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>ABBR</b> double tag element (<em>no explanation available</em>). <br>
;; .form (abbr . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:abbr" "basis.html#xhtml1:abbr"
(define abbr (generate-html-surface-function xhtml1:abbr "abbr" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>CITE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (cite . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:cite" "basis.html#xhtml1:cite"
(define cite (generate-html-surface-function xhtml1:cite "cite" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>VAR</b> double tag element (<em>no explanation available</em>). <br>
;; .form (var . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:var" "basis.html#xhtml1:var"
(define var (generate-html-surface-function xhtml1:var "var" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>KBD</b> double tag element (<em>no explanation available</em>). <br>
;; .form (kbd . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:kbd" "basis.html#xhtml1:kbd"
(define kbd (generate-html-surface-function xhtml1:kbd "kbd" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>SAMP</b> double tag element (<em>no explanation available</em>). <br>
;; .form (samp . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:samp" "basis.html#xhtml1:samp"
(define samp (generate-html-surface-function xhtml1:samp "samp" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>CODE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (code . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:code" "basis.html#xhtml1:code"
(define code (generate-html-surface-function xhtml1:code "code" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>DFN</b> double tag element (<em>no explanation available</em>). <br>
;; .form (dfn . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dfn" "basis.html#xhtml1:dfn"
(define dfn (generate-html-surface-function xhtml1:dfn "dfn" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>STRONG</b> double tag element (<em>no explanation available</em>). <br>
;; .form (strong . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:strong" "basis.html#xhtml1:strong"
(define strong (generate-html-surface-function xhtml1:strong "strong" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>EM</b> double tag element (<em>no explanation available</em>). <br>
;; .form (em . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:em" "basis.html#xhtml1:em"
(define em (generate-html-surface-function xhtml1:em "em" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>BR</b> single tag element (<em>no explanation available</em>). <br>
;; .form (br . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, clear. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:br" "basis.html#xhtml1:br"
(define br (generate-html-surface-function xhtml1:br "br" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>BDO</b> double tag element (<em>no explanation available</em>). <br>
;; .form (bdo . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: dir. <p>Optional attributes: id, class, style, title, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, lang, xml:lang. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:bdo" "basis.html#xhtml1:bdo"
(define bdo (generate-html-surface-function xhtml1:bdo "bdo" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>SPAN</b> double tag element (<em>no explanation available</em>). <br>
;; .form (span . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:span" "basis.html#xhtml1:span"
(define span (generate-html-surface-function xhtml1:span "span" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>A</b> double tag element (<em>no explanation available</em>). <br>
;; .form (a . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, charset, type, name, href, hreflang, rel, rev, accesskey, shape, coords, tabindex, onfocus, onblur, target. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:a" "basis.html#xhtml1:a"
(define a (generate-html-surface-function xhtml1:a "a" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>DEL</b> double tag element (<em>no explanation available</em>). <br>
;; .form (del . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite, datetime. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:del" "basis.html#xhtml1:del"
(define del (generate-html-surface-function xhtml1:del "del" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>INS</b> double tag element (<em>no explanation available</em>). <br>
;; .form (ins . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite, datetime. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:ins" "basis.html#xhtml1:ins"
(define ins (generate-html-surface-function xhtml1:ins "ins" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>CENTER</b> double tag element (<em>no explanation available</em>). <br>
;; .form (center . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:center" "basis.html#xhtml1:center"
(define center (generate-html-surface-function xhtml1:center "center" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>BLOCKQUOTE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (blockquote . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:blockquote" "basis.html#xhtml1:blockquote"
(define blockquote (generate-html-surface-function xhtml1:blockquote "blockquote" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>PRE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (pre . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, width, xml:space. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:pre" "basis.html#xhtml1:pre"
(define pre (generate-html-surface-function xhtml1:pre "pre" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>HR</b> single tag element (<em>no explanation available</em>). <br>
;; .form (hr . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, noshade, size, width. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:hr" "basis.html#xhtml1:hr"
(define hr (generate-html-surface-function xhtml1:hr "hr" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>ADDRESS</b> double tag element (<em>no explanation available</em>). <br>
;; .form (address . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:address" "basis.html#xhtml1:address"
(define address (generate-html-surface-function xhtml1:address "address" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>DD</b> double tag element (<em>no explanation available</em>). <br>
;; .form (dd . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dd" "basis.html#xhtml1:dd"
(define dd (generate-html-surface-function xhtml1:dd "dd" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>DT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (dt . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dt" "basis.html#xhtml1:dt"
(define dt (generate-html-surface-function xhtml1:dt "dt" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>DL</b> double tag element (<em>no explanation available</em>). <br>
;; .form (dl . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, compact. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dl" "basis.html#xhtml1:dl"
(define dl (generate-html-surface-function xhtml1:dl "dl" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>LI</b> double tag element (<em>no explanation available</em>). <br>
;; .form (li . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, value. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:li" "basis.html#xhtml1:li"
(define li (generate-html-surface-function xhtml1:li "li" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>DIR</b> double tag element (<em>no explanation available</em>). <br>
;; .form (dir . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, compact. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dir" "basis.html#xhtml1:dir"
(define dir (generate-html-surface-function xhtml1:dir "dir" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>MENU</b> double tag element (<em>no explanation available</em>). <br>
;; .form (menu . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, compact. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:menu" "basis.html#xhtml1:menu"
(define menu (generate-html-surface-function xhtml1:menu "menu" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>OL</b> double tag element (<em>no explanation available</em>). <br>
;; .form (ol . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, compact, start. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:ol" "basis.html#xhtml1:ol"
(define ol (generate-html-surface-function xhtml1:ol "ol" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>UL</b> double tag element (<em>no explanation available</em>). <br>
;; .form (ul . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, compact. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:ul" "basis.html#xhtml1:ul"
(define ul (generate-html-surface-function xhtml1:ul "ul" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>H6</b> double tag element (<em>no explanation available</em>). <br>
;; .form (h6 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h6" "basis.html#xhtml1:h6"
(define h6 (generate-html-surface-function xhtml1:h6 "h6" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>H5</b> double tag element (<em>no explanation available</em>). <br>
;; .form (h5 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h5" "basis.html#xhtml1:h5"
(define h5 (generate-html-surface-function xhtml1:h5 "h5" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>H4</b> double tag element (<em>no explanation available</em>). <br>
;; .form (h4 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h4" "basis.html#xhtml1:h4"
(define h4 (generate-html-surface-function xhtml1:h4 "h4" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>H3</b> double tag element (<em>no explanation available</em>). <br>
;; .form (h3 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h3" "basis.html#xhtml1:h3"
(define h3 (generate-html-surface-function xhtml1:h3 "h3" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>H2</b> double tag element (<em>no explanation available</em>). <br>
;; .form (h2 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h2" "basis.html#xhtml1:h2"
(define h2 (generate-html-surface-function xhtml1:h2 "h2" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>H1</b> double tag element (<em>no explanation available</em>). <br>
;; .form (h1 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h1" "basis.html#xhtml1:h1"
(define h1 (generate-html-surface-function xhtml1:h1 "h1" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>P</b> double tag element (<em>no explanation available</em>). <br>
;; .form (p . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:p" "basis.html#xhtml1:p"
(define p (generate-html-surface-function xhtml1:p "p" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>DIV</b> double tag element (<em>no explanation available</em>). <br>
;; .form (div . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:div" "basis.html#xhtml1:div"
(define div (generate-html-surface-function xhtml1:div "div" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>BODY</b> double tag element (<em>no explanation available</em>). <br>
;; .form (body . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, onload, onunload, background, bgcolor, text, link, vlink, alink. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:body" "basis.html#xhtml1:body"
(define body (generate-html-surface-function xhtml1:body "body" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>NOFRAMES</b> double tag element (<em>no explanation available</em>). <br>
;; .form (noframes . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:noframes" "basis.html#xhtml1:noframes"
(define noframes (generate-html-surface-function xhtml1:noframes "noframes" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>IFRAME</b> double tag element (<em>no explanation available</em>). <br>
;; .form (iframe . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, longdesc, name, src, frameborder, marginwidth, marginheight, scrolling, align, height, width. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:iframe" "basis.html#xhtml1:iframe"
(define iframe (generate-html-surface-function xhtml1:iframe "iframe" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>FRAME</b> single tag element (<em>no explanation available</em>). <br>
;; .form (frame . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, longdesc, name, src, frameborder, marginwidth, marginheight, noresize, scrolling. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:frame" "basis.html#xhtml1:frame"
(define frame (generate-html-surface-function xhtml1:frame "frame" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>FRAMESET</b> double tag element (<em>no explanation available</em>). <br>
;; .form (frameset . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, rows, cols, onload, onunload. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:frameset" "basis.html#xhtml1:frameset"
(define frameset (generate-html-surface-function xhtml1:frameset "frameset" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>NOSCRIPT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (noscript . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:noscript" "basis.html#xhtml1:noscript"
(define noscript (generate-html-surface-function xhtml1:noscript "noscript" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>SCRIPT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (script . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: type. <p>Optional attributes: charset, language, src, defer, xml:space. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:script" "basis.html#xhtml1:script"
(define script (generate-html-surface-function xhtml1:script "script" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>STYLE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (style . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: type. <p>Optional attributes: lang, xml:lang, dir, media, title, xml:space. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:style" "basis.html#xhtml1:style"
(define style (generate-html-surface-function xhtml1:style "style" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>LINK</b> single tag element (<em>no explanation available</em>). <br>
;; .form (link . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, charset, href, hreflang, type, rel, rev, media, target. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:link" "basis.html#xhtml1:link"
(define link (generate-html-surface-function xhtml1:link "link" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>META</b> single tag element (<em>no explanation available</em>). <br>
;; .form (meta . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: content. <p>Optional attributes: lang, xml:lang, dir, http-equiv, name, scheme. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:meta" "basis.html#xhtml1:meta"
(define meta (generate-html-surface-function xhtml1:meta "meta" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>BASE</b> single tag element (<em>no explanation available</em>). <br>
;; .form (base . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: href, target. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:base" "basis.html#xhtml1:base"
(define base (generate-html-surface-function xhtml1:base "base" (quote single)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>TITLE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (title . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:title" "basis.html#xhtml1:title"
(define title (generate-html-surface-function xhtml1:title "title" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>HEAD</b> double tag element (<em>no explanation available</em>). <br>
;; .form (head . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir, profile. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:head" "basis.html#xhtml1:head"
(define head (generate-html-surface-function xhtml1:head "head" (quote double)))

;; The LAML mirror of the XHMTL1.0 (frameset) <b>HTML</b> double tag element (<em>no explanation available</em>). <br>
;; .form (html . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir, xmlns. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:html" "basis.html#xhtml1:html"
(define html (generate-html-surface-function xhtml1:html "html" (quote double)))

